@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::duration::obj_DateTimeDuration;
 
-our $DATE = '2016-06-13'; # DATE
-our $VERSION = '0.017'; # VERSION
+our $DATE = '2016-06-29'; # DATE
+our $VERSION = '0.018'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,7 +33,7 @@ sub coerce {
 
     if ($coerce_to eq 'float(secs)') {
         # approximation
-        $res->{expr_coerce} = "($dt\->years * 365.25*86400 + $dt\->months * 30.4375*86400 + $dt\->weeks * 7*86400 + $dt\->days * 86400 + $dt\->hours * 3600 + $dt\->minutes * 60 + $dt\->seconds)";
+        $res->{expr_coerce} = "($dt\->years * 365.25*86400 + $dt\->months * 30.4375*86400 + $dt\->weeks * 7*86400 + $dt\->days * 86400 + $dt\->hours * 3600 + $dt\->minutes * 60 + $dt\->seconds + $dt\->nanoseconds * 1e-9)";
     } elsif ($coerce_to eq 'DateTime::Duration') {
         $res->{expr_coerce} = $dt;
     } else {
@@ -59,7 +59,7 @@ Data::Sah::Coerce::perl::duration::obj_DateTimeDuration - Coerce date from DateT
 
 =head1 VERSION
 
-This document describes version 0.017 of Data::Sah::Coerce::perl::duration::obj_DateTimeDuration (from Perl distribution Data-Sah-Coerce), released on 2016-06-13.
+This document describes version 0.018 of Data::Sah::Coerce::perl::duration::obj_DateTimeDuration (from Perl distribution Data-Sah-Coerce), released on 2016-06-29.
 
 =for Pod::Coverage ^(meta|coerce)$
 
